@@ -11,10 +11,8 @@ except ImportError:
     from yaml import Loader
 
 user_root = Path(Path.home().joinpath(".eadb"))
-
 user_config_file = user_root.joinpath("user.yml")
-
-local = user_root.joinpath("local")
+user_local = user_root.joinpath("local")
 
 user_config = None
 
