@@ -32,6 +32,11 @@ def event(args):
     analyze_catcher.show_analyze(args)
 
 
+def foo(args):
+    from .foo import fooooo
+    fooooo.do_test(args)
+
+
 def main(argv=None):
     if argv is None:
         argv = sys.argv[1:]
@@ -61,7 +66,10 @@ def main(argv=None):
     event_parser.set_defaults(func=event)
 
     # foo
-    foo = subparsers.add_parser('foo')
+    foo_parser = subparsers.add_parser('foo')
+    foo_parser.add_argument("interval", type=int, nargs='?')
+    foo_parser.add_argument("--times", metavar="times", type=int, default=999999)
+    foo_parser.set_defaults(func=foo)
 
     # repo
     repository = subparsers.add_parser('repo', help="apk repository")
